@@ -31,7 +31,6 @@ Main code for opsgenielib.
 
 """
 
-import re
 import logging
 import json
 import urllib.parse
@@ -347,7 +346,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
             results += response.json()['data']
         return results
 
-    def query_alerts(self, query):
+    def query_alerts(self, query, limit=2000):
         """Listing alerts based on a search query. Example: alerts query --query "teams=project9"."""
         search_query = urllib.parse.quote_plus(query)
         url = f'{self._alerts_url}?limit=100&query={search_query}'
@@ -358,7 +357,7 @@ class Opsgenie:  # pylint: disable=too-many-public-methods, too-many-instance-at
         if not response.json()['data']:
             return results
         while "next" in response.json()['paging']:
-            if not len(results) >= 2000:
+            if limit == 0 or not len(results) >= limit:
                 url = response.json()['paging']['next']
                 self._logger.debug('Making a call to "%s"', url)
                 response = self._session.get(url)
